pub struct Component<'a> { /* private fields */ }Expand description
A single component within a Registry.
Implementations
Sourceimpl Component<'_>
impl Component<'_>
Sourcepub fn hash(&self) -> Result<String, Error>
pub fn hash(&self) -> Result<String, Error>
Computes the component’s content hash by reading and hashing its source
(see content_hash).
Errors
Returns an error if the component’s source file cannot be read.
Sourcepub fn read_source(&self) -> Result<String, Error>
pub fn read_source(&self) -> Result<String, Error>
Reads the component’s Rust source from the registry.
Errors
Returns an error if the source file cannot be read.
Sourcepub fn dependencies(&self) -> &[Dependency]
pub fn dependencies(&self) -> &[Dependency]
The other components this component depends on.